function x = imdct(y,nbox)
%
% Performs inverse MDCT 
%  Usage
%    x = MDCT(y,nbox) 
%
%  Inputs
%    y        1-d vector containing MDCT coefficients 
%                    length(y) MUST BE A POWER OF 2
%    nbox     number of segments, each segment has length length(x)/nseg
%                    nbox  MUST BE A POWER OF 2
%
%  Outputs
%    x        inverse MDCT coefficients (n by 1).
%
%  Description
%    The vector y contains the MDCT coefficients of x, computed on nseg
%    equal-length segments.
%    Warning : mirror edge folding for the 2 edge segments.
%     
%*********************************************************************
	
y=y(:)';
n = length(y); 
D = log2(nbox); 


[dummy,D] = dyadlength(1:nbox);
    
m = n / nbox;

mm = m/2;
xi = (1 + (.5:(mm-.5))./mm)./2;
bp = sin( pi/2 .* xi );
bm = sqrt(1 - bp .^2); 
%
	
x = zeros(n,1);

for b=0:(nbox-1)
    c = y(b*m+1:(b+1)*m);  
    ybox = dct_iv(c);
    [xc,xl,xr] = unfold(ybox,bp,bm);
    x(b*m+1:(b+1)*m) = x(b*m+1:(b+1)*m) + xc';

    if b>0,
	x((b-1)*m+1:b*m) = x((b-1)*m+1:b*m) + xl';
    else
	x(1:m)   = x(1:m) + edgeunfold('left',xc,bp,bm)';
    end  
    
    if b < (nbox-1),
	x((b+1)*m+1:(b+2)*m) = x((b+1)*m+1:(b+2)*m) + xr';
    else         
        x(b*m+1:(b+1)*m) = x(b*m+1:(b+1)*m) + edgeunfold('right',xc,bp,bm)';
    end
    
end

    
