function y = mdct(x,nbox)
%
% Performs forward MDCT 
%  Usage
%    y = MDCT(x,nbox) 
%
%  Inputs
%    x        1-d signal:  length(x) MUST BE A POWER OF 2
%    nbox     number of segments, each segment has length length(x)/nseg
%                    nbox  MUST BE A POWER OF 2
%    
%  Outputs
%    y        MDCT coefficients (n by 1).
%
%  Description
%    The vector y contains the MDCT coefficients of x, computed on nseg
%    equal-length segments.
%    Warning : mirror edge folding for the 2 edge segments.
%     
%*********************************************************************


[n,J] = dyadlength(x);
if nargin < 2,
  D = min(7,J-3);
end
[dummy,D] = dyadlength(1:nbox);

%
% taper window
%
m = n / nbox;                       % length of boxes 
mm = m/2;
xi = (1 + (.5:(mm-.5))./mm)./2;
bp = sin( pi/2 .* xi );
bm = sqrt(1 - bp .^2); 

%
% packet table
%
n  = length(x);
y = zeros(n,1);
x = x(:)';
%

for b=0:(nbox-1)
    if(b == 0),                         % gather packet and
        xc = x(1:m);                    % left, right neighbors
	xl = edgefold('left',xc,bp,bm); % taking care of edge effects
	else
	    xl = xc;
	    xc = xr;          
	end
	if (b+1 < nbox)
            xr = x((b+1)*m+1:(b+2)*m);
	else
	    xr = edgefold('right',xc,bp,bm);
	end
	xbox = fold(xc,xl,xr,bp,bm);        % folding projection
	ybox = dct_iv(xbox);                % DCT-IV
        y(b*m+1:(b+1)*m) = ybox';
end
    
